@@ -5,11 +5,10 @@ from enum import Enum
 
 import kubernetes
 import six
-from six import raise_from
-
 from dagster import DagsterInstance, check
 from dagster.core.errors import _add_inner_exception_for_py2
 from dagster.core.storage.pipeline_run import PipelineRunStatus
+from six import raise_from
 
 DEFAULT_WAIT_TIMEOUT = 86400.0  # 1 day
 DEFAULT_WAIT_BETWEEN_ATTEMPTS = 10.0  # 10 seconds
@@ -282,8 +281,9 @@ class DagsterKubernetesClient:
             # status.failed represents the number of pods which reached phase Failed.
             if status.failed and status.failed > 0:
                 raise DagsterK8sError(
-                    "Encountered failed job pods for job {job_name} with status: {status}".format(
-                        job_name=job_name, status=status
+                    "Encountered failed job pods for job {job_name} with status: {status}, "
+                    "in namespace {namespace}".format(
+                        job_name=job_name, status=status, namespace=namespace
                     )
                 )
 
